@@ -25,6 +25,7 @@ templates_path = ["_templates"]
 exclude_patterns = ["_build", "Thumbs.db", ".DS_Store", "**.ipynb_checkpoints"]
 api_dir = HERE / "_static" / "api"
 api_rel_dir = "_static/api"
+bibtex_bibfiles = ["references.bib"]
 
 
 nitpicky = True  # Warn about broken links
@@ -39,8 +40,8 @@ extensions = [
     "sphinx.ext.napoleon",
     "sphinx_autodoc_typehints",
     "sphinxcontrib.bibtex",
-    "scanpydoc",
     "nbsphinx",
+    "scanpydoc",
     *[p.stem for p in (HERE / "extensions").glob("*.py")],
 ]
 
@@ -93,7 +94,7 @@ nbsphinx_timeout = 300
 
 # -- HTML styling ----------------------------------------------------------------------
 
-html_theme = "sphinx_rtd_theme"
+html_theme = "scanpydoc"
 # add custom stylesheet
 # https://stackoverflow.com/a/43186995/2340703
 html_static_path = ["_static"]
@@ -110,7 +111,7 @@ html_theme_options = dict(navigation_depth=4, logo_only=True)
 
 
 def setup(app):
-    app.add_css_file("custom.css")
+    pass
 
 
 # -- Supress 'reference target not found' errors ---------------------------------------
@@ -118,8 +119,9 @@ def setup(app):
 # See https://github.com/agronholm/sphinx-autodoc-typehints/issues/38 for more details.
 qualname_overrides = {
     "scipy.sparse.coo.coo_matrix": "scipy.sparse.coo_matrix",
-    "scirpy.io._datastructures.TcrCell": "scirpy.io.TcrCell",
-    "scirpy.io._datastructures.TcrChain": "scirpy.io.TcrChain",
+    "scirpy.io._datastructures.IrCell": "scirpy.io.IrCell",
+    "scirpy.io._datastructures.IrChain": "scirpy.io.IrChain",
+    "pandas.core.arrays.categorical.Categorical": "pandas.Categorical",
 }
 
 nitpick_ignore = [
