@@ -1,5 +1,4 @@
-from . import _base as base
-from ._base import embedding
+from .base import embedding
 from ._diversity import alpha_diversity
 from ._clonal_expansion import clonal_expansion
 
@@ -9,5 +8,6 @@ from ._group_abundance import group_abundance
 from ._spectratype import spectratype
 from ._vdj_usage import vdj_usage
 from ._repertoire_overlap import repertoire_overlap
+from ._clonotype_imbalance import clonotype_imbalance
 
-from ._clonotypes import clonotype_network, COLORMAP_EDGES, clonotype_network_igraph
+from ._clonotypes import clonotype_network, COLORMAP_EDGES
